@@ -15,7 +15,7 @@
 #include "QvernoteAPI.h"
 #include <QDebug>
 
-using namespace qvernote::api;
+
 
 class QEnmlContentHandler : public QXmlDefaultHandler {
 	enum EnmlElement {
@@ -42,9 +42,14 @@ class QEnmlContentHandler : public QXmlDefaultHandler {
 	};
 
 public:
-	QEnmlContentHandler(const Note& note, QvernoteAPI* hEvernote)
-	: m_Note(note),currentEnmlContentType(CT_NONE),isHtmlElementOpened(false), m_hEvernote(hEvernote), m_nTodoCount(0) {};
-	~QEnmlContentHandler() {};
+	QEnmlContentHandler(const Note& note, int maxHtmlSize = 0)
+	: m_Note(note),
+	  currentEnmlContentType(CT_NONE),
+	  isHtmlElementOpened(false),
+	  m_hEvernote(QvernoteAPI::Instance()),
+	  m_nTodoCount(0),
+	  m_maxHtmlSize(maxHtmlSize) { };
+	~QEnmlContentHandler() { };
 
 	bool startElement( const QString & namespaceURI, const QString & localName, const QString & , const QXmlAttributes & atts );
 	bool endElement ( const QString & namespaceURI, const QString & localName, const QString &  );
@@ -53,6 +58,8 @@ public:
 	bool endDocument () { m_sOutputHtml += "</body></html>"; /*qDebug() << __FUNCTION__ << m_sOutputHtml;*/ return true; }
 	QString	getHtml() { return m_sOutputHtml; }
 	int getTodoCount() { return m_nTodoCount; }
+
+	void setMaxHtmlSize(int maxHtmlSize) { m_maxHtmlSize = maxHtmlSize; }
 private:
 	EnmlElement decodeEnmlElement(const QString& elemName);
 	EnmlMediaType decodeEnmlMediaType(const QXmlAttributes & atts, QString& htmlTag);
@@ -65,6 +72,8 @@ private:
 	void openTodoElement(const QXmlAttributes & atts);
 
 	void appendCharacterData(const QString& ch, QString& htmlData);
+
+
 private:
 	Note m_Note;
 	QString m_sOutputHtml;
@@ -73,22 +82,21 @@ private:
 	bool	isHtmlElementOpened;
 	QvernoteAPI* m_hEvernote;
 	int m_nTodoCount;
-	//QString charDataBuffer;
+	int m_maxHtmlSize;
 };
 
 class QEnmlReader : public QXmlSimpleReader {
 public:
-	QEnmlReader(const Note& note, QvernoteAPI* hEvernote);
-	QEnmlReader(QvernoteAPI* hEvernote) : m_hEvernote(hEvernote) {}
+	QEnmlReader(const Note& note);
+	QEnmlReader() {}
 	virtual ~QEnmlReader();
 
-	bool parse();
-	bool parse(const Note& note);
+	bool parse(int maxHtmlSize = 0);
+	bool parse(const Note& note, int maxHtmlSize = 0);
 	QString getHtml() { return ((QEnmlContentHandler*)contentHandler())->getHtml(); }
 	int getTodoCount() { return ((QEnmlContentHandler*)contentHandler())->getTodoCount(); }
 
 private:
-	QvernoteAPI* m_hEvernote;
 	QXmlInputSource m_EnmlDocumentInputSource;
 	shared_ptr<QEnmlContentHandler> m_EnmlContentHandler;
 };
