@@ -8,6 +8,9 @@
 #include "QEnmlWriter.h"
 #include "QEnmlReader.h"
 #include <QWebElement>
+#ifdef Q_WS_MAEMO_5
+#include "QMaemoTextSelectionSupressor.h"
+#endif
 
 
 class QNoteEditWindow : public QvernoteWindow
@@ -15,10 +18,10 @@ class QNoteEditWindow : public QvernoteWindow
     Q_OBJECT
 
 public:
-    QNoteEditWindow(Note& note, bool bIsNewNote, QEnmlReader *reader = 0, QWidget *parent = 0);
+    QNoteEditWindow(Note& note, bool bIsNewNote, QWidget *parent = 0);
     ~QNoteEditWindow();
 
-    void hideEvent ( QHideEvent * );
+    void hideEvent(QHideEvent*);
 
 signals:
     void noteListUpdated();
@@ -41,8 +44,10 @@ public slots:
     void zoominView();
     void zoomoutView();
 
+    void setDirtyData() { hasDirtyData = true; }
+
     bool backgroundJobCallback() { return createNote(); }
-    void jobDoneCallback() { setProgressIndicator(false); emit noteListUpdated(); close(); }
+    void jobDoneCallback() { noteSaveSuccess(); }
     void jobFailedCallback() { noteSaveFailure(); }
 
     /* JS API slots */
@@ -51,6 +56,7 @@ public slots:
 private:
     bool createNote();
     void noteSaveFailure();
+    void noteSaveSuccess();
 
 private:
     Ui::QNoteEditWindowClass ui;
@@ -61,6 +67,10 @@ private:
     shared_ptr<QEnmlReader> enmlReader;
     shared_ptr<QEnmlWriter> enmlWriter;
     int nTodoTagCount;
+    bool	hasDirtyData;
+#ifdef Q_WS_MAEMO_5
+	QMaemoTextSelectionSupressor* supressor;
+#endif
 };
 
 #endif // QNOTEEDITWINDOW_H
