@@ -3,6 +3,7 @@
 
 #include <QtGui/QLabel>
 #include <QtGui/qpainter.h>
+#include "QThumbnailCreator.h"
 
 class QSyncProgressWidget : public QLabel
 {
@@ -13,12 +14,19 @@ public:
 		:QLabel("Please wait", parent) {
     	setAlignment(Qt::AlignCenter);
     	setAttribute(Qt::WA_TranslucentBackground);
+    	setWordWrap(true);
+
+
     };
 
     QSize sizeHint() const {
     	return QSize(500, 100);
     }
 
+    QSize size() const {
+    	return sizeHint();
+    }
+
     void showEvent(QShowEvent*) {
 		progressCount = 0;
 		setText(QString("Please wait..."));
@@ -29,6 +37,10 @@ public slots:
    		setText(QString("%1\n\n%2").arg(++progressCount).arg(data));
    	}
 
+   	void createNoteSnapshot(Guid guid) {
+   		new QThumbnailCreator(guid);
+   	}
+
 protected:
 	void paintEvent(QPaintEvent *event) {
 		QPainter p(this);
@@ -43,6 +55,7 @@ protected:
 
 private:
     int progressCount;
+    QThumbnailCreator* thumbnailCreator;
 };
 
 #endif // QSYNCPROGRESSWIDGET_H
